/*
 * Copyright (c) 2012-2014 Wind River Systems, Inc.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <zephyr.h>
#include <string.h>
#include <sys/printk.h>
#include <drivers/uart.h>
#include <device.h>

#include <logging/log.h>

#define UART_RX_BUFF_SIZE 256
#define UART_RX_TIMEOUT_MS 100

#define LOG_MODULE_NAME uart_async_demo
LOG_MODULE_REGISTER(LOG_MODULE_NAME);

static const struct device *uart;

static uint8_t m_uart_rx_buff[2][UART_RX_BUFF_SIZE];
static uint8_t *mp_current_rx_buff = m_uart_rx_buff[0];

static void uart_cb(const struct device *dev, struct uart_event *evt, void *user_data)
{
	int err = 0;
	uint8_t uart_string[UART_RX_BUFF_SIZE];

	switch (evt->type) {
	case UART_TX_DONE:
		LOG_INF("UART_TX_DONE");
		break;

	case UART_RX_RDY:
	    LOG_DBG("RX buffer offset: 0x%x", (uint32_t)&evt->data.rx.buf[evt->data.rx.offset]);
		memcpy(uart_string, &evt->data.rx.buf[evt->data.rx.offset], evt->data.rx.len);
		/* Make sure string is null terminated */
		uart_string[evt->data.rx.len] = 0;
		/* Print text string received from nRF52840 */
		LOG_INF("UART RX (%d): %s", evt->data.rx.len, log_strdup(uart_string));
		break;

	case UART_RX_DISABLED:
		LOG_INF("UART_RX_DISABLED");
		break;

	case UART_RX_BUF_REQUEST:
		/* Provide a new easyDMA buffer for UART RX */
		mp_current_rx_buff = (mp_current_rx_buff == m_uart_rx_buff[0]) ? m_uart_rx_buff[1] :
										       m_uart_rx_buff[0];
		err = uart_rx_buf_rsp(dev, mp_current_rx_buff, sizeof(m_uart_rx_buff[0]));
		if (err) {
			LOG_ERR("uart_rx_buf_rsp() failed. (err: %d)", err);
		}
		LOG_DBG("New buffer 0x%x", (uint32_t)mp_current_rx_buff);
		break;

	case UART_RX_BUF_RELEASED:
		LOG_DBG("Buffer released 0x%x", (uint32_t)evt->data.rx_buf.buf);
		break;

	case UART_TX_ABORTED:
		LOG_INF("UART_TX_ABORTED");
		break;

	default:
		break;
	}
}

static int uart_init(void)
{
	int err = 0;

	uart = device_get_binding("UART_1");
	if (!uart) {
		return -ENXIO;
	}

	err = uart_callback_set(uart, uart_cb, NULL);
	if (err) {
		return err;
	}

	return uart_rx_enable(uart, mp_current_rx_buff, sizeof(m_uart_rx_buff[0]),
			      UART_RX_TIMEOUT_MS);
}

void main(void)
{
	int err;

	uint8_t tx_message[] = "Message from nRF9160\n\r";
	uint16_t tx_len = sizeof(tx_message);

	err = uart_init();
	if (err) {
		printk("uart_init() failed. (err: %d)\n", err);
	}
	while (true) {
		k_sleep(K_MSEC(3000));
		/*err = uart_tx(uart, tx_message, tx_len, SYS_FOREVER_MS);
		if (err) {
			printk("uart_tx() failed. (err: %d)\n", err);
		}*/
	}
}
